@@ -5,6 +5,7 @@ from .solvers_abc import ABCSolver
 
 class data(TypedDict):
     Pmax: float
+    qp_max: float
     l1: float
     l2: float
     d: float
@@ -529,6 +530,7 @@ class StressSolver:
 
     preprocessed_data: data = dict(
         Pmax=None,
+        qp_max=None,
         a=None,
         b=None,
         d_d=None,
@@ -548,6 +550,7 @@ class StressSolver:
     )
 
     def preprocessor(self, data: dict, global_state: dict):
+        self.preprocessed_data['qp_max'] = data['settings']['strength']['qp_max']
         self.preprocessed_data['Pmax']=data['initial_cond']['Pmax']
         self.preprocessed_data['V']=data['initial_cond']['V']
         self.preprocessed_data['C'] = data['shell_size']['R3']
@@ -588,6 +591,7 @@ class StressSolver:
         C = p_data['C']
         mu_c = p_data['mu_c']
         rho_w = p_data['rho_w']
+        qp = p_data['qp_max']
 
         # Рабочая ширина ведущего пояска
         lp = C * 0.9
@@ -608,7 +612,7 @@ class StressSolver:
         fv = (1 + 0.0213 * v) / (1 + 0.133 * v) * f0
         T_N = N * n * np.cos(alpha) * (np.tan(alpha) + fv)
         T_1 = T_N / (P * np.pi * R_pr ** 2)
-        qp = 300E6
+        # qp = 300E6
         T_qp = qp * n * (a + b) * lp * fv * np.cos(alpha)
         T_2 = T_qp / (P * np.pi * R_pr ** 2)
         T_0 = T_1 + T_2
